import idx from 'idx';

export default function SearchResultHelper(urlHelper) {
  const { generateFundLink, generateStockLinkBySymbol, newsTagLink, driverPageLink, newsDetailLink } = urlHelper;

  const generateTradeSearchLink = (item, type) => {
    let link;

    switch (type) {
      case 'FUND':
        link = generateFundLink(item.localName, item.symbol);
        break;
      case 'QUOTE':
      default:
        link = generateStockLinkBySymbol(item.symbol);
    }

    return link;
  };

  const hotTagsResponseHelper = data => {
    const items = idx(data, _ => _.data.items);

    if (!items) return [];

    return items.map(tag => ({
      tagName: tag.tag,
      link: `${newsTagLink}/${tag.tag}`,
    }));
  };

  const hotDriverDataHelper = items => {
    if (!items) return [];

    return items.map(driver => ({
      avatarPicture: driver.avatarPicture,
      driverId: driver.driverId,
      driverName: driver.nickname,
      return1year: driver.return1year || driver.return1Year,
      link: `${driverPageLink}/${driver.driverId}`,
    }));
  };

  const hotDriversResponseHelper = data => {
    const items = idx(data, _ => _.data.items);

    if (!items) return [];

    return hotDriverDataHelper(items);
  };

  const hotTradesResponseHelper = data => {
    const items = idx(data, _ => _.data.data);

    if (!items) return [];

    return items.map(trade => ({
      localName: trade.localName,
      link: generateTradeSearchLink(trade, trade.market),
    }));
  };

  const recentSearchDataHelper = keywordArr => {
    if (!keywordArr) return [];

    return keywordArr.map(keyword => ({
      keyword,
    }));
  };

  const searchTradesResponseHelper = data => {
    const items = idx(data, _ => _.data.data);
    let quoteFunds = [];
    let news = [];
    let oldDrivers = [];

    if (!items) {
      return null;
    }

    quoteFunds =
      items.quoteFunds &&
      items.quoteFunds.map(trade => ({
        market: trade.market,
        code: trade.code || trade.displayNameLocal,
        type: trade.type,
        mtype: trade.mtype,
        symbol: trade.symbol,
        chName: trade.chName,
        enName: trade.enName || trade.displayName,
        exchange: trade.exchange,
        link: generateTradeSearchLink(trade, trade.objectType),
      }));

    news =
      items.news &&
      items.news.map(n => ({
        newsId: n.newsId,
        title: n.title,
        summary: n.summary,
        publishAt: n.publishAt,
        link: `${newsDetailLink}/${n.newsId}`,
      }));

    oldDrivers = hotDriverDataHelper(items.oldDrivers);

    return {
      quoteFunds,
      news,
      oldDrivers,
    };
  };

  return {
    generateTradeSearchLink,
    hotTagsResponseHelper,
    hotDriverDataHelper,
    hotDriversResponseHelper,
    hotTradesResponseHelper,
    recentSearchDataHelper,
    searchTradesResponseHelper,
  };
}
