import React from 'react';
import PropTypes from 'prop-types';
import classnames from 'classnames/bind';
import styles from './AnueSearchInput.scss';

const cx = classnames.bind(styles);

class AnueSearchInput extends React.Component {
  static propTypes = {
    customAttribute: PropTypes.objectOf(PropTypes.any),
    customWrapperStyles: PropTypes.objectOf(PropTypes.any),
    customInputStyles: PropTypes.objectOf(PropTypes.any),
    customIconStyles: PropTypes.objectOf(PropTypes.any),
    customInputClassName: PropTypes.string,
    shouldAlwaysDisplayInput: PropTypes.bool,
    onIconClick: PropTypes.func,
    onInputChange: PropTypes.func,
    onInputFocus: PropTypes.func,
    onInputBlur: PropTypes.func,
    onInputPressEnter: PropTypes.func,
    onDisplayChange: PropTypes.func,
    theme: PropTypes.string,
    placeholder: PropTypes.string,
    defaultValue: PropTypes.string,
  };
  static defaultProps = {
    customAttribute: null,
    customWrapperStyles: null,
    customInputStyles: null,
    customIconStyles: null,
    shouldAlwaysDisplayInput: false,
    theme: null, // mobile | desktop
    placeholder: '搜尋新聞、代碼或名稱',
    defaultValue: null,
    customInputClassName: null,
    onDisplayChange: () => {},
    onIconClick: () => {},
    onInputChange: () => {},
    onInputFocus: () => {},
    onInputBlur: () => {},
    onInputPressEnter: () => {},
  };
  constructor(props) {
    super(props);

    this.state = {
      value: props.defaultValue || '',
      shouldDisplayInput: props.shouldAlwaysDisplayInput || props.theme !== 'mobile',
    };
  }

  handleChange = e => {
    const { onInputChange } = this.props;
    const value = e.target.value;

    this.setState({
      value,
    });
    onInputChange(value);
  };

  handleClickIcon = () => {
    const { onIconClick, shouldAlwaysDisplayInput, onDisplayChange } = this.props;
    const { value, shouldDisplayInput } = this.state;

    onIconClick(value);

    if (!shouldAlwaysDisplayInput) {
      this.setState({
        shouldDisplayInput: !shouldDisplayInput,
      });
      onDisplayChange(!shouldDisplayInput);
    }
  };

  handleKeyDown = e => {
    if (e.keyCode === 13) {
      const { onInputPressEnter } = this.props;
      const { value } = this.state;

      if (value) {
        onInputPressEnter(value);
      }
    }
  };

  handleResetValue = () => {
    this.setState({
      value: '',
    });
  };

  render() {
    const {
      placeholder,
      onInputFocus,
      onInputBlur,
      customAttribute,
      customWrapperStyles,
      customInputStyles,
      customIconStyles,
      theme,
      customInputClassName,
    } = this.props;
    const { shouldDisplayInput } = this.state;

    return (
      <div className={cx('anue-search-input--wrapper', theme, customInputClassName)} style={customWrapperStyles}>
        <input
          className={cx('anue-search-input', theme, {
            display: shouldDisplayInput,
          })}
          onChange={this.handleChange}
          onFocus={onInputFocus}
          onBlur={onInputBlur}
          onKeyDown={this.handleKeyDown}
          style={customInputStyles}
          placeholder={placeholder}
          {...customAttribute}
        />
        <div className={cx('search-icon', theme)} onClick={this.handleClickIcon} style={customIconStyles} />
      </div>
    );
  }
}

export default AnueSearchInput;
