import React from 'react';
import { mount } from 'enzyme';
import AnueSearchInput from '../AnueSearchInput';

describe('<AnueSearchInput /> component', () => {
  let makeSubject;
  const defaultProps = {
    customAttribute: null,
    customWrapperStyles: null,
    customInputStyles: null,
    customIconStyles: null,
    shouldAlwaysDisplayInput: false,
    theme: null, // mobile | desktop
    placeholder: '搜尋新聞、代碼或名稱',
    defaultValue: null,
    onIconClick: jest.fn(),
    onInputChange: jest.fn(),
    onInputFocus: jest.fn(),
    onInputBlur: jest.fn(),
    onInputPressEnter: jest.fn(),
  };

  beforeEach(() => {
    jest.resetModules();
    jest.resetAllMocks();
    makeSubject = params => mount(<AnueSearchInput {...defaultProps} {...params} />);
  });

  it('should display the search input and the search icon both', () => {
    const subject = makeSubject();

    expect(subject.find('.anue-search-input.display').length).toBe(1);
  });

  describe('When the prop theme is mobile', () => {
    let subject;

    beforeEach(() => {
      subject = makeSubject({
        theme: 'mobile',
      });
    });

    it('should display the search icon only on the initial render.', () => {
      expect(subject.find('.anue-search-input.display').length).toBe(0);
    });

    it('should toggle the search input only on the initial render if the search icon is clicked', () => {
      const icon = subject.find('.search-icon');

      expect(subject.find('.anue-search-input.display').length).toBe(0);
      icon.simulate('click');
      expect(subject.find('.anue-search-input.display').length).toBe(1);
      icon.simulate('click');
      expect(subject.find('.anue-search-input.display').length).toBe(0);
    });

    it('should not hide the input even the props.theme is mobile if the props.shouldAlwaysDisplayInput is true', () => {
      subject = makeSubject({
        theme: 'mobile',
        shouldAlwaysDisplayInput: true,
      });
      const icon = subject.find('.search-icon');

      expect(subject.find('.anue-search-input.display').length).toBe(1);
      icon.simulate('click');
      expect(subject.find('.anue-search-input.display').length).toBe(1);
    });
  });

  describe('The actions to call the private methods with the props', () => {
    let subject;

    beforeEach(() => {
      subject = makeSubject({
        theme: 'mobile',
      });
    });

    it('should call props.onInputChange and pass the input value', () => {
      subject = makeSubject();

      subject.find('.anue-search-input').simulate('change', { target: { value: 'test' } });

      expect(defaultProps.onInputChange).toHaveBeenCalledWith('test');
    });

    it('should call props.onIconClick and pass the input value', () => {
      subject = makeSubject();

      subject.find('.anue-search-input').simulate('change', { target: { value: 'test' } });
      subject.find('.search-icon').simulate('click');

      expect(defaultProps.onIconClick).toHaveBeenCalledWith('test');
    });

    it('should call props.onInputPressEnter and pass the input value', () => {
      subject = makeSubject();

      const input = subject.find('.anue-search-input');

      input.simulate('change', { target: { value: 'test' } });
      input.simulate('keyDown', { keyCode: 13 });

      expect(defaultProps.onInputPressEnter).toHaveBeenCalledWith('test');
    });
  });
});
