import React from 'react';
import { mount } from 'enzyme';
import AnueSearchRealtimeResult from '../AnueSearchRealtimeResult';
import { MOCK_HOT_SEARCH } from '../__mocks__/searchData';

describe('<AnueSearchRealtimeResult /> component', () => {
  let makeSubject;
  const defaultProps = {
    hotTags: null,
    hotTrades: null,
    hotDrivers: null,
    recentSearch: null,
    tradeResult: null,
    newsResult: null,
    driversResult: null,
    searchTradeResult: null,
    searchDriverResult: null,
    searchNewsResult: null,
    searchString: null,
    customWrapperStyles: null,
    theme: 'mobile',
    onRecentSearchRowClick: jest.fn(),
    onRecentSearchRowRemoveClick: jest.fn(),
    onRecentSearchRemoveAllClick: jest.fn(),
  };

  beforeEach(() => {
    jest.resetModules();
    jest.resetAllMocks();
    makeSubject = params => mount(<AnueSearchRealtimeResult {...defaultProps} {...params} />);
  });

  it('should display the hot search sections based on the data exist', () => {
    const subject = makeSubject();

    expect(subject.find('.search-result-content-wrapper.display').length).toBe(0);

    subject.setProps({
      hotTags: MOCK_HOT_SEARCH.hotTags,
      hotTrades: MOCK_HOT_SEARCH.hotTrades,
      hotDrivers: MOCK_HOT_SEARCH.hotDrivers,
      recentSearch: MOCK_HOT_SEARCH.recentSearch,
    });

    expect(subject.find('.search-result-content-wrapper.display').length).toBe(4);
  });

  it('should display the result result and hide the hot search', () => {
    const subject = makeSubject();

    expect(subject.find('.search-sections').length).toBe(0);
    expect(subject.find('.hot-sections').length).toBe(1);

    subject.setProps({
      searchString: '五漢廢言',
    });

    expect(subject.find('.search-sections').length).toBe(1);
    expect(subject.find('.hot-sections').length).toBe(0);
  });
});
