import React from 'react';
import PropTypes from 'prop-types';
import classnames from 'classnames/bind';
import styles from './Compare.scss';
import gaDataset from '../../utils/gaDataset';

const DEFAULT_REGULATION_MSG = <p>最多可選擇4項</p>;
const cx = classnames.bind(styles);

function Compare({
  items,
  clickItemCloseCb,
  ctaCb,
  prerequisiteMsg,
  regulationMsg,
  btnText,
  isMobile,
  gaEventForClose,
  gaEventForStart,
}) {
  // eslint-disable-next-line
  const blocks = Array.apply(null, Array(isMobile ? 2 : 4)).map((cur, idx) => {
    return items[idx];
  });
  const _prerequisiteMsg =
    prerequisiteMsg ||
    (isMobile ? (
      <p>
        需選擇2項，<br />以開始進行比較
      </p>
    ) : (
      <p>最少選擇2項，以開始進行比較</p>
    ));
  const _regulationMsg = regulationMsg || DEFAULT_REGULATION_MSG;

  const handleClickCta = () => {
    if (typeof ctaCb === 'function') {
      ctaCb(items);
    }
  };

  const handleClickClose = id => {
    if (typeof clickItemCloseCb === 'function') {
      clickItemCloseCb(id);
    }
  };

  const getGaEvent = event => {
    return event ? gaDataset(event) : null;
  };

  return (
    <div className={cx('comparison', { display: items.length > 0 })}>
      {blocks.map((b, idx) => (
        <div className={cx('block')} key={(b && b.id) || idx}>
          {b && b.name ? (
            <div>
              <span
                className={cx('close')}
                // eslint-disable-next-line react/jsx-no-bind
                onClick={handleClickClose.bind(this, b.id)}
                {...getGaEvent(gaEventForClose)}
              />
              <p className={cx('content')}>{b.name}</p>
            </div>
          ) : (
            <div className={cx('empty')}>{idx > 1 ? _regulationMsg : _prerequisiteMsg}</div>
          )}
        </div>
      ))}
      <button
        className={cx('cta', { 'is-enable': items.length > 1 })}
        onClick={handleClickCta}
        {...getGaEvent(gaEventForStart)}
      >
        {btnText}
      </button>
    </div>
  );
}

Compare.propTypes = {
  items: PropTypes.arrayOf(
    PropTypes.shape({
      name: PropTypes.string,
      id: PropTypes.string,
    })
  ).isRequired,
  ctaCb: PropTypes.func.isRequired,
  clickItemCloseCb: PropTypes.func.isRequired,
  prerequisiteMsg: PropTypes.oneOfType([PropTypes.string, PropTypes.element]),
  regulationMsg: PropTypes.oneOfType([PropTypes.string, PropTypes.element]),
  btnText: PropTypes.string,
  isMobile: PropTypes.bool,
  gaEventForClose: PropTypes.shape({
    dataPrefix: PropTypes.arrayOf(PropTypes.string),
    category: PropTypes.string.isRequired,
    action: PropTypes.string.isRequired,
    label: PropTypes.string.isRequired,
  }),
  gaEventForStart: PropTypes.shape({
    dataPrefix: PropTypes.arrayOf(PropTypes.string),
    category: PropTypes.string.isRequired,
    action: PropTypes.string.isRequired,
    label: PropTypes.string.isRequired,
  }),
};

Compare.defaultProps = {
  prerequisiteMsg: '',
  regulationMsg: '',
  btnText: '開始比較',
  isMobile: false,
  gaEventForClose: null,
  gaEventForStart: null,
};

export default Compare;
