const SEARCH_HISTORY_STORED_COOKIE_NAME = 'anue.search.history';

export default function AnueCookie(env) {
  const isProd = env === 'prod';
  const cookieDomain = isProd ? '.cnyes.com' : '.cnyes.cool';
  const getSearchCookies = () => {
    const history = `; ${document.cookie}`
      .split(`; ${SEARCH_HISTORY_STORED_COOKIE_NAME}=`)
      .pop()
      .split(';')
      .shift();
    let _history = [];

    if (history) {
      try {
        _history = JSON.parse(history);
      } catch (e) {
        console.log('the stored values has incorrect format. Store the new value and truncate the old data', e);
        _history = [];
      }
    }

    return _history;
  };

  return {
    getSearchCookies,
    setSearchCookies: ({ string, shouldDelete = false, cookieLimit = 5 }) => {
      const next = getSearchCookies();
      let legalSearchStr = string;

      if (!legalSearchStr) {
        return;
      }
      if (legalSearchStr.length > 30) {
        legalSearchStr = legalSearchStr.substring(0, 30);
      }

      if (next.length > 0) {
        if (shouldDelete && next.indexOf(legalSearchStr) > -1) {
          next.splice(next.indexOf(legalSearchStr), 1);
        } else if (next.indexOf(legalSearchStr) > -1) {
          // Do nothing if the keyword is duplicated.
          return;
        } else {
          next.push(legalSearchStr);
        }

        while (next.length > cookieLimit) {
          next.shift();
        }

        document.cookie = `${SEARCH_HISTORY_STORED_COOKIE_NAME}=${JSON.stringify(
          next
        )}; domain=${cookieDomain}; path=/`;
      } else {
        document.cookie = `${SEARCH_HISTORY_STORED_COOKIE_NAME}=${JSON.stringify([
          legalSearchStr,
        ])}; domain=${cookieDomain}; path=/`;
      }
    },
    removeSearchCookies: () => {
      document.cookie = `${SEARCH_HISTORY_STORED_COOKIE_NAME}=${JSON.stringify([])}; domain=${cookieDomain}; path=/`;
    },
    cookieDomain,
  };
}
