/**
 * Get the corresponding url.
 * @param {*} env prod | stage | beta | int
 */
export default function AnueLink(env) {
  const isProd = env === 'prod';
  const isApiProd = env !== 'int' && env !== 'beta';
  const cnyesBaseUrl = isProd ? 'cnyes.com' : `${env}.cnyes.cool`;
  const cookieDomain = isProd ? '.cnyes.com' : '.cnyes.cool';
  const apiBaseUrl = isApiProd ? 'cnyes.com' : `${env}.cnyes.cool`;

  const wwwChannelLink = `https://www.${cnyesBaseUrl}`;
  const newsChannelLink = `https://news.${cnyesBaseUrl}`;
  const cryptoChannelLink = `https://crypto.${cnyesBaseUrl}`;
  const fundChannelLink = `https://fund.${cnyesBaseUrl}`;
  const stockTalk = `https://stock.${cnyesBaseUrl}`;
  const globalStockTalk = `https://global-stock.${cnyesBaseUrl}`;
  const invest = `https://invest.${cnyesBaseUrl}`;

  const forexChannelLink = `${wwwChannelLink}/forex/reuters`;
  const cryptoChannelBTCLink = `${cryptoChannelLink}/BTC/24h`;
  const wdStockNewsLink = `${newsChannelLink}/news/cat/wd_stock`;
  const forexNewsLink = `${newsChannelLink}/news/cat/forex`;
  const cryptoNewsLink = `${newsChannelLink}/news/cat/bc_virtual`;
  const bcNewsLink = `${newsChannelLink}/news/cat/bc`;
  const fundNewsLink = `${newsChannelLink}/news/cat/fund`;
  const twStockNewsLink = `${newsChannelLink}/news/cat/tw_stock`;
  const usStockNewsLink = `${newsChannelLink}/news/cat/us_stock`;
  const cnStockNewsLink = `${newsChannelLink}/news/cat/cn_stock`;

  const driverFundDetailLink = `${invest}/funds/detail`;
  const driverPageLink = `${invest}/drivers`;
  const newsTagLink = `${newsChannelLink}/tag`;
  const newsDetailLink = `${newsChannelLink}/id`;
  const hotTagsApiUrl = `https://api.${apiBaseUrl}/api/v1/news/recommend/tags`;
  const hotDriversApiUrl = `https://driver.api.${apiBaseUrl}/driver/api/v1/drivers?order=1y&sort=desc&page=1&size=3`;
  const hotTradesApiUrl = `https://ws.api.${apiBaseUrl}/ga/api/v1/pageViewHot`;
  const anueSearchAllApiUrl = `https://ess.api.${apiBaseUrl}/search/api/v1/siteSearch/main?q=`;

  // .net link only have prod env
  const wdStockChannelLink = 'https://www.cnyes.com/global/IndexImmediateQuotedPrice/';
  const archiveUSStock = 'https://www.cnyes.com/archive/usastock/';

  const toUrlParams = params => {
    return Object.keys(params)
      .filter(key => !!params[key])
      .map(key => `${encodeURIComponent(key)}=${encodeURIComponent(params[key])}`)
      .join('&');
  };

  return {
    generateStockLinkBySymbol: symbol => {
      const symbolSplit = String(symbol).split(':');

      if (!symbolSplit || symbolSplit.length < 2) {
        return '';
      }

      if ((symbolSplit[0] === 'TWS' || symbolSplit[0] === 'TWG') && symbolSplit[2] === 'STOCK') {
        return `${invest}/twstock/${symbolSplit[0]}/${symbolSplit[1]}`;
      }

      if ((symbolSplit[0] === 'TWS' || symbolSplit[0] === 'TSE') && symbolSplit[2]) {
        // symbolSplit[2]==='STOCK' || symbolSplit[2]==='INDEX'
        return `${stockTalk}/market/TWS:${symbolSplit[1]}:${symbolSplit[2]}`;
      }

      if ((symbolSplit[0] === 'CNS' || symbolSplit[0] === 'HKS') && symbolSplit[2] === 'STOCK') {
        return `${globalStockTalk}/market/${symbol}`;
      }

      if (symbolSplit[0] === 'USS' && symbolSplit[2] === 'STOCK') {
        return `${invest}/usstock/detail/${symbolSplit[1]}`;
      }

      if (symbolSplit[0] === 'FX') {
        return `${wwwChannelLink}/forex/reuters/realtime/${symbol}`;
      }

      if (symbolSplit[0] === 'EOD') {
        return `https://www.cnyes.com/futures/html5chart/${symbolSplit[1]}.html`;
      }

      if (symbolSplit[0] === 'CC' && symbolSplit[1]) {
        const crypto = symbolSplit[1];

        return `${cryptoChannelLink}/${crypto}`;
      }

      if (symbolSplit[0] === 'GI' && symbolSplit[1]) {
        return `${wwwChannelLink}/index/${symbolSplit[1]}`;
      }

      return '';
    },
    generateFundLink: (displayName, cnyesId) => {
      const fundName = `${displayName}`.replace(/<(?:.|\n)*?>/gm, '');

      return `${driverFundDetailLink}/${fundName}/${cnyesId}`;
    },
    generateETFLink: symbol => {
      const symbolSplit = String(symbol).split(':');

      if (!symbolSplit || symbolSplit.length < 2) {
        return '';
      }

      if (symbolSplit[0] === 'TWS' && symbolSplit[2] === 'STOCK') {
        return `${stockTalk}/market/TWS:${symbolSplit[1]}:${symbolSplit[2]}`;
      }

      if (symbolSplit[0] === 'USS' && symbolSplit[2] === 'STOCK') {
        return `${invest}/etf/us/detail/${symbolSplit[1]}/overview`;
      }

      return '';
    },
    generateSearchResultLink: ({ keyword, backLink }) => {
      const params = {
        keyword,
        aink: backLink,
      };

      return `${wwwChannelLink}/search/all?${toUrlParams(params)}`;
    },
    cnyesBaseUrl,
    cookieDomain,
    wwwChannelLink,
    newsChannelLink,
    cryptoChannelLink,
    fundChannelLink,
    stockTalk,
    globalStockTalk,
    invest,
    forexChannelLink,
    cryptoChannelBTCLink,
    wdStockNewsLink,
    forexNewsLink,
    cryptoNewsLink,
    bcNewsLink,
    fundNewsLink,
    twStockNewsLink,
    usStockNewsLink,
    cnStockNewsLink,
    wdStockChannelLink,
    archiveUSStock,
    driverFundDetailLink,
    driverPageLink,
    newsTagLink,
    newsDetailLink,
    hotTagsApiUrl,
    hotDriversApiUrl,
    anueSearchAllApiUrl,
    hotTradesApiUrl,
    toUrlParams,
  };
}
